/*****************************************************************************
* vim:sw=8:ts=8:si
*
* Title        : Microchip ENC28J60 Ethernet Interface Driver
* Author        : Pascal Stang (c)2005
* Modified by Guido Socher
* Copyright: GPL V2
*
*This driver provides initialization and transmit/receive
*functions for the Microchip ENC28J60 10Mb Ethernet Controller and PHY.
*This chip is novel in that it is a full MAC+PHY interface all in a 28-pin
*chip, using an SPI interface to the host processor.
*
*
*****************************************************************************/

#ifndef ENC28J60_H
#define ENC28J60_H

#include <stdint.h>

extern uint8_t enc28j60ReadOp(uint8_t op, uint8_t address);
extern void enc28j60WriteOp(uint8_t op, uint8_t address, uint8_t data);
extern void enc28j60ReadBuffer(uint16_t len, uint8_t* data);
extern void enc28j60WriteBuffer(uint16_t len, uint8_t* data);
extern void enc28j60SetBank(uint8_t address);
extern uint8_t enc28j60Read(uint8_t address);
extern void enc28j60Write(uint8_t address, uint8_t data);
extern void enc28j60PhyWrite(uint8_t address, uint16_t data);
extern void enc28j60clkout(uint8_t clk);
extern void enc28j60Init(uint8_t* macaddr);
extern void enc28j60PacketSend(uint16_t len, uint8_t* packet);
extern uint16_t enc28j60PacketReceive(uint16_t maxlen, uint8_t* packet);
extern uint8_t enc28j60getrev(void);
extern uint8_t enc28j60linkup(void);

extern void enc28j60LedConfig(uint8_t a, uint8_t b, uint8_t stlen, uint8_t stretch);
// a and b
#define LED_TX			0x01
#define LED_RX			0x02
#define LED_COL			0x03
#define LED_LINK		0x04
#define LED_FDX			0x05
#define LED_TXRX		0x07
#define LED_OFF			0x09
#define LED_ON			0x08
#define LED_FASTBLINK		0x0a
#define LED_SLOWBLINK		0x0b
#define LED_LINKRX		0x0c
#define LED_LINKTXRX		0x0d
#define LED_FDXCOL		0x0e

// stlen
#define LED_STRETCH_40MS	0x00
#define LED_STRETCH_70MS	0x01
#define LED_STRETCH_140MS	0x02

#endif
